==> mingwrt-5.1.1-mingw32-src.tar.xz: mingwrt-5.1.1/mingwex/clockset.c <==
/*
 * clockset.c
 *
 * Implementation of the clock_settime() element of the POSIX clock API.
 *
 * $Id: clockset.c,v f2287469341d 2017/12/15 20:58:19 keith $
 *
 * Written by Keith Marshall <keithmarshall@users.sourceforge.net>
 * Copyright (C) 2017, MinGW.org Project
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 */
#include "clockapi.h"

int clock_settime( clockid_t clock_id, const struct timespec *timeval )
{
  /* Standard API function, first implemented in POSIX.1b-1993, to
   * set (or reset) the time value to be indicated by the specified
   * clockid_t entity, if permissable.
   *
   * FIXME: Decide which clockid_t entities should support any such
   * adjustment; for the time being, deny all such requests.
   */
  errno = ((timeval != NULL) && __clock_api_is_valid( clock_id ))
    ? EPERM : EINVAL;
  return -1;
}

/* $RCSfile: clockset.c,v $: end of file */

==> mingwrt-5.2.2-mingw32-src.tar.xz: mingwrt-5.2.2/mingwex/clockset.c <==
/*
 * clockset.c
 *
 * Implementation of the clock_settime() element of the POSIX clock API.
 *
 * $Id: clockset.c,v 7a19e2864602 2018/10/18 08:50:58 keith $
 *
 * Written by Keith Marshall <keithmarshall@users.sourceforge.net>
 * Copyright (C) 2017, 2018, MinGW.org Project
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next
 * paragraph) shall be included in all copies or substantial portions of the
 * Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 *
 */
#include "clockapi.h"

int clock_settime( clockid_t clock_id, const struct timespec *timeval )
{
  /* Standard API function, first implemented in POSIX.1b-1993, to
   * set (or reset) the time value to be indicated by the specified
   * clockid_t entity, if permissable.
   *
   * FIXME: Decide which clockid_t entities should support any such
   * adjustment; for the time being, deny all such requests.
   */
  errno = ((timeval != NULL) && (__clock_api_is_valid( clock_id ) != NULL))
    ? EPERM : EINVAL;
  return -1;
}

/* $RCSfile: clockset.c,v $: end of file */
